==========
flask-hype
==========

.. image:: https://travis-ci.org/bninja/flask-hype.png
   :target: https://travis-ci.org/bninja/flask-hype

.. image:: https://coveralls.io/repos/bninja/flask-hype/badge.png?branch=master
   :target: https://coveralls.io/r/bninja/flask-hype?branch=master
